==> fujicoin-22.0.tar.gz: fujicoin-22.0/src/qt/locale/fujicoin_ug.ts <==
<TS version="2.1" language="ug">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">ئوڭ كۇنۇپكا چېكىلسە ئادرېس ياكى بەلگىنى تەھرىرلەيدۇ</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>يېڭى ئادرېس قۇر</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">يېڭى(&amp;N)</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>نۆۋەتتە تاللىغان ئادرېسنى سىستېما چاپلاش تاختىسىغا كۆچۈرىدۇ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">كۆچۈر(&amp;C)</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">تاقا(&amp;L)</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>نۆۋەتتە تاللانغان ئادرېسنى تىزىمدىن ئۆچۈرىدۇ</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">ئىزدەيدىغان ئادرېس ياكى بەلگىنى كىرگۈزۈڭ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>نۆۋەتتىكى بەتكۈچتىكى سانلىق مەلۇماتنى ھۆججەتكە چىقىرىدۇ</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>چىقار(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>ئۆچۈر(&amp;D)</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">تەڭگىنى ئەۋەتىدىغان ئادرېسنى تاللاڭ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">تەڭگىنى تاپشۇرۇۋالىدىغان ئادرېسنى تاللاڭ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">تاللا(&amp;H)</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">يوللاش ئادرېسى</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">تاپشۇرۇۋېلىش ئادرېسى</translation>
    </message>
    <message>
        <source>These are your Fujicoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">بۇلار سىز Fujicoin چىقىم قىلىدىغان ئادرېس. تەڭگە چىقىم قىلىشتىن ئىلگىرى، سومما ۋە تاپشۇرۇۋېلىش ئادرېسىنىڭ توغرا ئىكەنلىكىنى تەكشۈرۈشنى ئۇنۇتماڭ.</translation>
    </message>
    <message>
        <source>These are your Fujicoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">بۇ Fujicoin تاپشۇرۇۋېلىشقا ئىشلىتىدىغان ئادرېسىڭىز. «قوبۇللاش» بەتكۈچتىكى «يېڭى تاپشۇرۇۋېلىش ئادرېسى قۇر» توپچىنى چېكىپ يېڭى ئادرېس قۇرالايسىز.
پەقەت «ئەنئەنىۋى(legacy)» تىپتىكى ئادرېسلا ئىمزانى قوللايدۇ.</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">ئادرېس تىزىمىنى چىقار</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See https://en.wikipedia.org/wiki/Comma-separated_values</extracomment>
        <translation type="unfinished">ھۆججەت پەش بىلەن ئايرىلىدۇ</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">ئادرېس تىزىمىنى %1 غا ساقلاشنى سىناۋاتقاندا خاتالىق كۆرۈلدى. قايتا سىناڭ.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">چىقىرالمىدى</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">بەلگە</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">ئادرېس</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بەلگە يوق)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>FujicoinGUI</name>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Fujicoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بەلگە يوق)</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">ئادرېس</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">بەلگە</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بەلگە يوق)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بەلگە يوق)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">بەلگە</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بەلگە يوق)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See https://en.wikipedia.org/wiki/Comma-separated_values</extracomment>
        <translation type="unfinished">ھۆججەت پەش بىلەن ئايرىلىدۇ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">بەلگە</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">ئادرېس</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">چىقىرالمىدى</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">چىقار(&amp;E)</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">نۆۋەتتىكى بەتكۈچتىكى سانلىق مەلۇماتنى ھۆججەتكە چىقىرىدۇ</translation>
    </message>
    </context>
</TS>

==> fujicoin-23.0.tar.gz: fujicoin-23.0/src/qt/locale/fujicoin_ug.ts <==
<TS version="2.1" language="ug">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">ئوڭ كۇنۇپكا چېكىلسە ئادرېس ياكى بەلگىنى تەھرىرلەيدۇ</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">يېڭى ئادرېس قۇر</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">يېڭى(&amp;N)</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">نۆۋەتتە تاللىغان ئادرېسنى سىستېما چاپلاش تاختىسىغا كۆچۈرىدۇ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">كۆچۈر(&amp;C)</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">تاقا(&amp;L)</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">نۆۋەتتە تاللانغان ئادرېسنى تىزىمدىن ئۆچۈرىدۇ</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">ئىزدەيدىغان ئادرېس ياكى بەلگىنى كىرگۈزۈڭ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">نۆۋەتتىكى بەتكۈچتىكى سانلىق مەلۇماتنى ھۆججەتكە چىقىرىدۇ</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">چىقار(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">ئۆچۈر(&amp;D)</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">تەڭگىنى ئەۋەتىدىغان ئادرېسنى تاللاڭ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">تەڭگىنى تاپشۇرۇۋالىدىغان ئادرېسنى تاللاڭ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">تاللا(&amp;H)</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">يوللاش ئادرېسى</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">تاپشۇرۇۋېلىش ئادرېسى</translation>
    </message>
    <message>
        <source>These are your Fujicoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">بۇلار سىز Fujicoin چىقىم قىلىدىغان ئادرېس. تەڭگە چىقىم قىلىشتىن ئىلگىرى، سومما ۋە تاپشۇرۇۋېلىش ئادرېسىنىڭ توغرا ئىكەنلىكىنى تەكشۈرۈشنى ئۇنۇتماڭ.</translation>
    </message>
    <message>
        <source>These are your Fujicoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">بۇ Fujicoin تاپشۇرۇۋېلىشقا ئىشلىتىدىغان ئادرېسىڭىز. «قوبۇللاش» بەتكۈچتىكى «يېڭى تاپشۇرۇۋېلىش ئادرېسى قۇر» توپچىنى چېكىپ يېڭى ئادرېس قۇرالايسىز.
پەقەت «ئەنئەنىۋى(legacy)» تىپتىكى ئادرېسلا ئىمزانى قوللايدۇ.</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">ئادرېس تىزىمىنى چىقار</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">ھۆججەت پەش بىلەن ئايرىلىدۇ</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">ئادرېس تىزىمىنى %1 غا ساقلاشنى سىناۋاتقاندا خاتالىق كۆرۈلدى. قايتا سىناڭ.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">چىقىرالمىدى</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">بەلگە</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">ئادرېس</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بەلگە يوق)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>FujicoinGUI</name>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">خاتالىق</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Fujicoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بەلگە يوق)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;خەتكۈچ</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">خاتالىق</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">خاتالىق</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">ئادرېس</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">بەلگە</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بەلگە يوق)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بەلگە يوق)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">بەلگە</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بەلگە يوق)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Other</source>
        <translation type="unfinished">باشقىلىرى</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">ھۆججەت پەش بىلەن ئايرىلىدۇ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">بەلگە</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">ئادرېس</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">چىقىرالمىدى</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">خاتالىق</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">چىقار(&amp;E)</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">نۆۋەتتىكى بەتكۈچتىكى سانلىق مەلۇماتنى ھۆججەتكە چىقىرىدۇ</translation>
    </message>
    </context>
</TS>
